---
title: "A 0.006 mm2 1.2 uW Analog-to-Time Converter for Asynchronous Bio-Sensors"
date: 2018-07-23T15:26:46+01:00
draft: false
toc: true
type: posts
math: true
tags:
  - publication
  - CMOS
  - circuits
  - data-converter
  - biomedical
---

Lieuwe B. Leene, Timothy G. Constandinou

Department of Electrical and Electronic Engineering, Imperial College London, SW7 2BT, UK

Centre for Bio-Inspired Technology, Institute of Biomedical Engineering, Imperial College London, SW7 2AZ, UK

# 1 Abstract

This work presents a low-power analogue-to-time converter (ATC) for integrated bio-sensors. The proposed circuit facilitates the direct conversion of electrode biopotential recordings into time-encoded digital pulses with high efficiency without prior signal amplification. This approach reduces the circuit complexity for multi-channel instrumentation systems and allows asynchronous digital control to maximise the potential power savings during sensor inactivity. A prototype fabricated using a 65 nm CMOS technology is demonstrated with measured characteristics. Experimental results show an input-referred noise figure of 3.8 μ V<sub>rms<sub> for a 11 kHz signal bandwidth while dissipating 1.2 μ W from a 0.5 V supply and occupying 60\\(\times\\)80 μ m²  silicon area. This compact configuration is enabled by the proposed asynchronous readout that shapes the mismatch components arising from the multi-bit quantiser and the use of capacitive feedback.

# 2 Introduction

The current trend in sensor systems is to integrate many analogue sensors together with larger digital systems to provide smart data collection for miniaturised wearables or low cost system-in-package (SiP) electronics [^2][^1]. The digital oriented design flow of these systems compels designers to look for sensor interfaces that accommodate the trends in CMOS technology scaling and smaller supply voltages for digital power reduction. For this reason many data converters and sensing circuits have utilised voltage controlled oscillators (VCO) to convert analogue signals into a periodic digital waveform where information is encoded by its frequency. This type of conversion is highly applicable at every technology node and the time encoded output is considerably more robust than the voltage output of conventional amplifiers when considering supply noise and the process, voltage and temperature (PVT) variations. The time-domain concept has seen extensive use in recent publications because the voltage to frequency conversion provides high gain and exceptional dynamic range [^5][^4][^3] that can also accommodate conventional chopper techniques [^6][^7].

The conversion from analogue to frequency is not the only means by which analogue circuits can encode signals in the time-domain. It is well known that both synchronous [^8] and asynchronous [^9] oversampling modulators will generate a pulse-width-modulated (PWM) output bitstream. However these realisations conventionally do not perform integration in the time-domain and instead use charge pumps that suffer from typical drawbacks in advanced CMOS technologies such as gain degradation and limited voltage swing [^10]. In contrast the modulating characteristic of oscillators can negate component mismatch in any proceeding digital-to-analogue conversion since the digital output inherently provides data-weighted averaging [^5].

{{< figure src="/images/jssc2018/obi.svg" title="Figure 1: The proposed Analogue-to-Time Converter (ATC) that provides closed loop conversion of an analogue input voltage into an asynchronous multi-bit digital data stream." width="500" >}}

In order to retain high performance and minimise the requirement of ideal analogue components, time-based systems should be designed in a fashion where only small error signals are processed in the analogue domain with constrained linearity. Signals with large dynamics should be time-encoded and manipulated with robust digital logic. The proposed ATC realisation that follows this concept is shown in Fig. 1. This topology presents an asynchronous delta-sigma modulator (ADSM) that accumulates a phase difference between two oscillators to realise time-based integration and utilises capacitive feedback to linearise the conversion.

Here the sensor's voltage fluctuations on V<sub>IN<sub> modulate the pulse width of the PWM signal generated by the phase detector by combining multiple phases from each stage in the oscillator. In this fashion the output bit-stream D<sub>OUT<sub> can in effect resolve finer quantisation levels. In contrast to prior oscillator-based systems that are clocked, the asynchronous operation proposed here enables high-speed signal processing with oscillator-based filters [^11] or a continuous-time digital core [^12]. Both avoid the need for a high speed clock when processing a large number of recording channels and can therefore enable substantial power saving.

This work is a first step towards realising a sensor system that fundamentally only processes using time-encoded signals and can potentially operate using a supply voltage of only several hundred millivolts since the circuit can accurately convert millivolt level signals without prior analogue signal amplification [^14][^13]. This is because oscillator based integrators can operate with a voltage headroom close to transistor threshold voltage without diminishing loop gain or dynamic range. This advantage is not diminished by practical issues and large common-mode interference or electrode offset can be rejected because the sensor input is capacitively coupled to the main feedback loop. There are a number of established techniques such as using a DC servo loop or performing ripple rejection that prevent these issues from degrading circuit performance [^15]. This means that the voltage appearing at V<sub>X<sub> well controlled through feedback and that the amplifier can maximise power-efficiency-factor (PEF) [^16] without requiring additional voltage overhead to accommodate voltage fluctuation at its input.

This paper presents the implementation and modelling aspects of the oscillator based ATC using the following organisation: Section 3 details the instrumentation topology and Section 4 describes the corresponding transistor level implementation, Section 9 discusses the impact of technology and mismatch parameters of this circuit, Section 12 presents the measured results of a fabricated prototype, and Section 13 concludes this work.

# 3 Concept and ATC Architecture

This section introduces the operating principle and circuit dynamics of the proposed instrumentation system that is used to sense intra-cortical neural activity using a conventional electrode instrumentation setup. Such a scenario would record activity in-vivo or ex-vivo from the 1 Hz to 10 kHz frequency band where the signals are no larger than a few millivolts in amplitude[^17]. The circuit sensitivity must match the noise characteristics of the electrode or biological tissue and target a noise floor of around 50 nV/\rtxt{Hz}[^18]. These sensitivity conditions require the circuit dissipate several microamps and easily leads to a circuit bandwidth much larger than 10 kHz. For this reason this ATC will provide gain for a bandwidth exceeding 10 kHz since it is more resource effective to rely on proceeding processing stages to perform filtering when necessary.

{{< figure src="/images/jssc2018/obi_sys.svg" width="500" >}}

{{< figure src="/images/jssc2018/obi_blk.svg" title="Figure 2: Detailed system topology in a) and equivalent analytical model in b) of the proposed chopper stabilised ATC." width="500" >}}

A block diagram of the proposed architecture is detailed in Fig. 2a. For clarity, this shows the single ended equivalent of the fully differential circuit that was implemented. The difference in potential between two electrode inputs V<sub>R<sub> & V<sub>IN<sub> is chopped at the chopper frequency f<sub>chp<sub> to generate a up-modulated voltage waveform that couples the input onto V<sub>X<sub> through C<sub>I<sub>. The essential mechanism here is that signals appearing on V<sub>X<sub> induce a current that feeds into two oscillators with different polarities after being demodulated. This current forces the oscillators accumulate a relative phase difference because the phase is dependent on the integral of injected current [^19]. This phase difference is then evaluated for each oscillator tap using XOR logic to yield multiple time-encoded PWM signals that can also be chopped using digital logic. The resulting digital signal is capacitively coupled onto V<sub>X<sub> in parallel to close the loop. This is the main signal amplifying path that realises a first-order asynchronous ΔΣ modulator and this sense using N phase detectors in parallel represents asynchronous quantization of the phase difference with a resolution of log<sub>2<sub>(1+N) bits. Using this interpretation we can construct the corresponding analytical model that is shown in Fig. 2b and will assist in deducing the design's parameter dependencies.

$$  H(s) = \frac{ 1 }{ s / k_1 + N f } \approx \frac{1}{s\cdot \frac{N C_{gate} V_{RG}}{Gm}+\frac{C_F}{C_I}\frac{C_U}{C_U+\:\:\text{\makebox[-3pt][l]{\\(\nearrow\\)}}C_G/N}} $$

$$  f = {\frac{C_F}{C_{I}+C_{F}}} \cdot \frac{N C_{U}}{C_{F}+N C_{U}+ \text{\makebox[-3pt][l]{\\(\nearrow\\)}}C_{G}} $$

First the expression in Eq. 1 can be derived to characterise the signal amplifying loop. The feedback factor \\(f\\) evaluated in Eq. 2 corresponds to the capacitive coupling of a particular PWM phase Q on to V<sub>X<sub> with respect to the capacitors C<sub>I<sub>, C<sub>F<sub>, C<sub>G<sub>, C<sub>U<sub>. In this case C<sub>G<sub> can be digitally tuned to provide varying gain settings (41-53 dB). The oscillator's integration factor k<sub>1<sub> is derived by evaluating the impulse sensitivity function (ISF). The ISF captures how the oscillator phase is affected as a function of charge being injected into the virtual supply of the oscillator V<sub>R<sub> [^19]. Following the derivation for Eq. 2 in [^11] this factor can be assumed constant and is simply dependent on the transconductance Gm, loading capacitance of each delay stage C<sub>gate<sub>, and the voltage across the oscillator V<sub>RG<sub> such that k<sub>1<sub>=Gm/(N C<sub>gate<sub> V<sub>RG<sub>).

The second control loop is used to reject near-DC aggressors that will appear at the input of the main transconductor. Chopping will prevent the input-referred noise profile from being corrupted by flicker noise but in turn several large tones will appear at harmonics of f<sub>chp<sub> because off-set is being up-modulated. Moreover because this structure is not providing narrowband amplification the feedback must actively suppress these tones to avoid the output from being saturated and distorted. These components are integrated with a gain of approximately A<sub>ripple<sub>=k<sub>1<sub>/f<sub>chp<sub> which induces a 90\\(^\circ\\) phase shift. The phase-shift can be corrected for by using the chopper clock that is delayed by 1/4<sup>th<sup> of the period when demodulating Q to recover the off-set. The flicker rejection further depends on the transfer function F(s) which represents how the recovered signal is smoothed and fed back onto V<sub>X<sub>. Using a charge pump in addition to the pseudo-resistor R<sub>P<sub> will yield an expression for F(s) according to Eq. 3 where C<sub>L<sub> and I\tss{Δ} represent the main integration capacitor and charge pump bias current respectively. This is also shown in Fig. 2.

$$  F(s) = \frac{N   I_{\Delta}}{s (C_{L} C_{I} R_{P}   s + C_{L} + C_{I})} $$

Combining F(s) and A<sub>ripple<sub> will then predict how the noise aggressors at V<sub>x<sub> are removed. The frequency dependent response in Fig. 3 evaluates this control mechanism at different points in the loop using the following implemented circuit parameters: N=5, f<sub>chp<sub>=75 kHz, C<sub>I<sub>=288 fF, C<sub>G<sub>=69 fF, C<sub>F<sub>=C<sub>U<sub>=14 fF, R<sub>P<sub>=100 MΩ, C<sub>L<sub>=1.6 pF, I\tss{Δ}=5 nA. This shows the influence of noise at the input (e²<sub>flk<sub>) with respect to the ripple at the ATC output and the fluctuations on V<sub>X<sub> as a function of frequency. First notice the increased chopper frequency enables this circuit to increase its bandwidth and reject more of the low-frequency band including common-mode signals that asymmetrically couple onto V<sub>X<sub>. In addition the second order low-pass characteristic provides increased rejection of the chopper and oscillator tones such that the two control loops operate in isolation. A known drawback of increasing f<sub>chp<sub> is the reduction in input impedance but as shown in Sec. 10 this reduction can be mitigated with technology scaling and using a smaller value for C<sub>I<sub>.

{{< figure src="/images/jssc2018/noise_tf.svg" title="Figure 3: The closed loop response of the flicker rejection loop due to input-referred noise e²<sub>flk<sub> evaluated with respect to the ripple magnitude seen at Q (solid), the feedback seen at V<sub>X<sub> (dotted), and the open loop response F(s)\\(\cdot\\)A<sub>ripple<sub> (dashed)." width="500" >}}

Given these dynamics there is still important distinction to be made with regards to the rate of information seen at the output and the 3 dB bandwidth for signal amplification that in this case is the product of \\(f\\) k<sub>1<sub>\\(\approx\\)250 kHz. The digital output will encode an effective number of bits (ENOB) that relates to the ATC's precision (i.e. SNDR) and presents pulse width information of every cycle that in this case is oversampled by N parallel phases. However for one phase the entropy rate can be estimated in terms of f<sub>osc<sub> (SNDR-1.76)/6.02. This highlights an important motivation for time-domain processing since this information rate may easily be 10\\(\times\\) larger than a clocked digital bit-stream that maximally yields 1 bit per clock cycle. Optimistically this implies that time-domain techniques achieve a proportional boost in power efficiency since the digital power dissipation is a function of f<sub>osc<sub> even though a higher rate of information is being processed. For the latter to hold we must require the analogue and oscillator sub-blocks to operate with negligible power budget.

# 4 Circuit Implementation

{{< figure src="/images/jssc2018/obi_sch.svg" title="Figure 4: The transistor level implementation of the ATC circuit in Fig. 2a. Here the complementary structure in a) represents the main transconductor; b) represents the pseudo-differential oscillator where each delay cell is shown in c); The flicker rejection stage is shown in d) where only the grey section is replicated for each phase. Note that all devices have their body connected to the corresponding supplies with the exception of M\tss{5-8} which have the body connected to the drain of M<sub>9<sub>. Furthermore M\tss{13-16} and M\tss{21-22} their body connected to V<sub>R<sub> and either terminal of C<sub>L<sub> respectively." width="500" >}}

The transistor schematic for the proposed ATC is presented in Fig. 4 and the sizing of each device is listed in Table 1. This circuit can be segmented into four parts corresponding to the transconductor, oscillator, delay stage, and flicker rejection circuit. Each sub-block, including the capacitor array, will be described below. This configuration uses two bias voltages V<sub>BN<sub> & V<sub>BP<sub> to source the annotated drain currents. Both of these voltages are derived on-chip using a simple current mirror structure and a 1 μ A off-chip reference. Furthermore an external reference voltage V<sub>C<sub> is used to control the common mode voltage of V<sub>R<sub> that is placed at V<sub>DD<sub>/2. Note that the 65 nm technology used here provides transistors that can be configured with 150 mV (lvt), 250 mV (vt), and 350 mV (hvt) threshold voltages (V<sub>TH<sub>). The lvt option is used exclusively to reduce the supply voltage to 0.5 V with the exception of M\tss{23-24} which use a 250 mV threshold.

Table 1:  Device Sizing in micrometers with the labels from Fig. 4
|		Device | Size (W/L) | Device | Size (W/L) |
|----|----|----|----|
|		M<sub>0<sub> 			| 26/5 				| M\tss{15-16} 			| 0.2/2.5 |
|		M\tss{1-2} 		| 16/0.25 		| M\tss{17-18} 			| 2/5 |
|		M\tss{3-4} 		| 2/1 				| M\tss{19-20} 			| 10/0.2 |
|		M\tss{5-6} 		| 4/0.5 			| M\tss{21-22} 			| 1.6/0.4 |
|		M\tss{7-8} 		| 0.8/1.4 		| M\tss{23-24} 			| 0.96/4 |
|		M<sub>9<sub> 			| 32/0.1 			| Logic 						| 0.3/0.1 |
|		M<sub>10<sub> 		| 6/5 				| Switch<sub>CHP<sub> 	| 1/0.1 (P<sub>type<sub>) |
|		M\tss{11-12} 	| 1.5/2.4 		| Switch<sub>X<sub> 		| 1/0.2 (N<sub>type<sub>) |
|		M\tss{13-14} 	| 2.3/2.5 		| C<sub>L<sub> 					| 21/21 |

## 5 Low-Noise Transconductor

The complementary style transconductor (Fig. 4a) is adopted from [^20] to exploit two aspects of oscillator based integration. The first is that the operating conditions and transistor characteristics do not influence the loop gain of the time-based integrator but rather effect the noise characteristics which are already improved due to current recycling. Secondly the voltage fluctuation across V<sub>X<sub> & V<sub>S<sub> is negligible particularly if all transistors in the Gm cell and oscillator are in sub-threshold operation. This implies that the circuit can operate reliably with a narrow V<sub>DS<sub> margin for each transistor since the gate voltage V<sub>X<sub> is carefully controlled in closed loop and there is little concern for instability. The self-biasing cascodes M<sub>3,6<sub> biases each input pair with a V<sub>DS<sub> that is highly correlated with the threshold voltage and provides abundant dummy devices to improve matching. The cascodes also reduce the parasitic gate capacitance of the transconductor by reducing the Miller effect that may otherwise lead to increased noise.

Achieving good noise performance for this configuration relies on minimising the drain current noise from each transistor in the oscillator when referred to the input[^7]. As the ratio I<sub>M10<sub>/I<sub>M0<sub> is reduced the NEF of this circuit will asymptotically decrease to the optimal value for this topology (i.e. η\rtxt{2})[^21]. On the other hand I<sub>M10<sub> controls the oscillation frequency which must be sufficiently large such that the oscillator harmonics lie out of band similar to the chopper harmonics.

The lack of filtering requirements allows the asynchronous implementation to chose a large f<sub>osc<sub> by reducing C<sub>gate<sub> such that any intermodulation products with f<sub>chp<sub> do not fall in-band [^22] and the circuit size is minimised. When using this configuration as a clocked ΔΣ modulator[^23] this freedom is lost because k<sub>1<sub> must be directly related to the oversampling ratio. If the system can afford a fast oversampling clock f<sub>osc<sub> can still be large but it would be more effective to chose f<sub>osc<sub> close to the Nyquist frequency such that the harmonics of f<sub>osc<sub> can be removed reliably during decimation as they have already be shaped by the loop-filter. This circuit also constrains the minimum value for N due to the limited linearity of the transconductor for a given input range. This is because the ratio 2V<sub>DD<sub> \\(f\\)/(N+1) determines the maximum peak-to-peak amplitude of the error signal seen at V<sub>X<sub>. Fortunately for high-gain applications \\(f\\) is small resulting in sub-millivolt signal at V<sub>X<sub> and therefore high linearity can be achieved while using just a few phases in parallel.

## 6 Pseudo-Differential Oscillator

The main feature of the oscillators (Fig. 4b) used by this ATC is that it uses differential logic and the delay stage (Fig. 4c) is biased around the middle of the supply making the digital buffers for phase detection more power efficient. The corresponding advantages are best contrasted with a simple inverter delay cell that uses a capacitive load to ground. First the inverter based implementation would experience voltage spikes on V<sub>R<sub> due to discontinuous conduction of current but would also contaminate the ground with the AC current pulses. The configuration adopted from [^24] exhibits continuous charging & discharging currents that can be confined within the virtual supply nodes V<sub>G<sub>/V<sub>R<sub>. Moreover using switching transistors that are several μ m² in size to load for the preceding gate reduces the sensitivity to process variation with smaller area requirements since the transistor gate capacitance achieves a higher density than poly-poly or metal-oxide-metal (MOM) capacitors.

## 7 Flicker Rejection Stage

The flicker removal circuit (Fig. 4d) biases the input of the transconductor by feeding back common mode and differential mode signals using a cross coupled load to enable low voltage operation without an additional common-mode-feedback circuit[^20]. The differential feedback provides flicker cancellation by demodulating the digital output using a switched current DAC that integrates on C<sub>L<sub> which is a large vertical metal-insulator-metal (MIM) capacitor placed over the analogue circuitry. The diode connected devices M\tss{21-22} represent pseudo-resistors of 100 MΩ that provide a resistive path to V<sub>X<sub> and further smooths high frequency tones from f<sub>chp<sub> and f<sub>osc<sub>. A significant variation in resistive value is inherently expected but it is important to note that it does not influence the signal amplifying path and the non-dominant poles are far away from the 8 kHz bandwidth of F(s) in Eq. 3 by virtue of not using a second analogue integrator that may compromise stability. The common mode feedback regulates V<sub>R<sub> with respect to V<sub>C<sub> by biasing the common mode of V<sub>X<sub>. For this loop the gain arises from transconductance ratio gm\tss{M19-M20}/gm\tss{M23-M24} together with the drain resistance ratio rds<sub>M10<sub>/(rds<sub>M0<sub>+rds<sub>M9<sub>). This readily provides over 30 dB of gain with the dominant pole provided by the pseudo-resistors that will also attenuate the input common mode signals.

## 8 Capacitive Feedback Network

Both electrode inputs feed into separate capacitor arrays that off-set the scaled PWM signal generated at the output to calculate the differential error signal on V<sub>X<sub>. Each array is 20\\(\times\\)23 μ m² in size and uses 28 elements in a 4 by 7 configuration with 2.7\\(\times\\)2.7 μ m²  horizontal MOM capacitors with 6 fingers on metal layers 2-7. The following allocation is used: C<sub>I<sub>=17\\(\times\\), C<sub>F<sub>=1\\(\times\\), C<sub>U<sub>=5\\(\times\\), C<sub>G<sub>=[0-5]\\(\times\\). The particular configuration in Fig. 2 can readily accommodate changes in dynamic range or adjustments in N. This is because \\(f\\) is dominated by the ratio C<sub>F<sub>/C<sub>I<sub> such that the design can freely change the number of phases being fed back without significantly changing the amplification dynamics. Additionally increasing C<sub>F<sub> will extend the dynamic range of the circuit since the noise floor will remain unchanged while providing less signal gain and having excessive circuit bandwidth.

# 9 The Impact of Technology Parameters

This section further highlights two features of the proposed topology that can be taken advantage of in advanced CMOS technologies where mismatch and process variation are the leading concern for designers. First we will summarise the scaling properties that arise when chopping in the input signal and secondly we will show that also for the asynchronous case the time-domain integration fundamentally helps with mitigating mismatch in digital to analogue conversion using a behavioural model as example.

## 10 CMOS Scaling of Chopper Impedance

First consider the input impedance R<sub>IN<sub> of the simple chopper structure used here[^25]. For sensor applications it is essential to maintain a large input impedance that avoids signal attenuation because many integrated sensors exhibit a source resistance of several M\\(\Omega\\).

$$  C_{I} = 10   C_{GM} = \frac{20}{3}   W L   C_{ox} $$

$$  f_{chp} = 2 f_{cor} = \frac{2   K_F}{W   L   C^2_{ox}   e^2_{gd}} $$

The expression in Eq. 4 is first used select C<sub>I<sub> as 10\\(\times\\) the parasitic capacitance C<sub>GM<sub> seen on V<sub>X<sub> due the transconductor. This configuration avoids degrading the noise performance during amplification[^17]. C<sub>I<sub> is further equated in terms of the width W and length L of the input transistors. The chopper frequency is placed at exactly twice the corner frequency f<sub>cor<sub> which is the frequency at which the flicker noise is equal to the thermal noise floor e²<sub>gd<sub> of the target input-referred noise profile. Rearrangement of the terms will yield Eq. 5 which uses the trap density K<sub>F<sub> to estimate for flicker noise for a specific fabrication process[^26].

$$  R_{IN} = \frac{1}{2   C_{I}   f_{chp} } = \frac{ 3  C_{ox}   e^2_{gd} }{80   K_F } $$

{{< figure src="/images/jssc2018/sizing.svg" title="Figure 5: Chopper based input impedance as a function of CMOS technology using typical process parameters K<sub>F<sub>=3.2e-38 and C<sub>ox<sub>=1.6e-12 [F/μ m²]/L where L is the technology feature size in nanometre with the oxide thickness being estimated as 1/50 times the feature size." width="500" >}}

Eq. 6 calculates the expected input resistance and provides a first order estimation of amplifier impedance with respect to process parameters. The fact that R<sub>IN<sub> depends linearly on C<sub>ox<sub> implies that input resistance can be improved by using more advanced technologies. The expected values for R<sub>IN<sub> are plotted in Fig. 5 as a function of CMOS technology with varying noise requirements. Eventually the gate leakage will inhibit this trend as the associated shot-noise limits the sensitivity for technologies beyond 65 nm. This result primarily constrains the selection of transistor size[^25] that in turn determines f<sub>chp<sub> and f<sub>osc<sub>.

## 11 Modulated Mismatch in Oscillators

Mismatch due to process variation is the primary cause of distortion during multi-bit signal conversion. Minimising this source of nonlinearity is essential for both synchronous and asynchronous ΔΣ modulators because mismatch in the feedback DAC is not shaped by the loop filter [^27]. Fortunately the modulating property of the oscillator can remove this distortion if the phase readout is performed in a parallel fashion [^5]. Here we will concisely demonstrate that property arises because the mismatch induced components are simply being averaged and induce a DC-offset together with tones at the harmonic components of f<sub>osc<sub>. This uses a mapping that relates the phase difference \\(x\\) to the generated PWM waveform as a function of time \\(\tau\\) defined in Eq. 7. The following expression in Eq. 8 then evaluates the analogue feedback voltage that appears on V<sub>X<sub> in the ideal case for a given a phase difference of Δφ between the two oscillators.

$$  A(\tau,x) \triangleq\begin{cases} 1  &  \tau   (mod\: 1) \: < \:x  0  &  \text{otherwise} \end{cases} $$

$$  V_{X}(t) =  f \cdot \sum_{k=0}^{N-1} \underbrace{A( t \cdot f_{osc}+\frac{k}{N}\:,\: \Delta \phi )}_{Q_{k}(t)} $$

$$  Q_{k}(t) = (1+\frac{\sigma_{C,k}}{C_U})   A(  t \cdot f_{osc} + \frac{k}{N} \: , \: \sigma_{\tau-\mu,k} + \Delta \phi) $$

There are two independent sources of mismatch for each phase: the deviation in capacitor weights of C<sub>U<sub> σ<sub>C,k<sub> and the differential delay variation in oscillator stages as a fraction of the oscillation period σ\tss{τ,k} that includes the digital gates generating Q (i.e. inverters and XOR-gate). These are used to formulate Eq. 9 which considers a particular phase of Q(t) and the random mismatch variables that have process dependent normal distributions. The variation in delay will locally increase/decrease the pulse-width of Q for a specific phase \\(k\\). This is a time-invariant component of the gate delay while Δφ and T<sub>osc<sub> are signal dependent. Precisely formulating the cumulative variation of σ\tss{τ} will relate the transistor sizing, gate capacitance, and threshold voltage of each delay during operation.

Notice that A is a linear function of Δφ with a gain of 1 for the DC component of the PWM output which can be further expanded to extract the high frequency behaviour. However by design these components are intentionally avoided which should reveal that that the capacitor weights are always uniformly averaged irrespective Δφ. Closed-loop operation feeds back each σ\tss{τ,k} such that the sum all components has zero mean, that is σ\tss{τ-μ,k}\ = σ\tss{τ,k}-(\\(\sum_{k=0}^{N-1}\\) σ\tss{τ,k}/N). The residual variation in delay for each phase inevitably induces spurs at at harmonics of f<sub>osc<sub>.

{{< figure src="/images/jssc2018/vco_model.svg" title="Figure 6: A continuous-time multi-phase VCO model for evaluating parameter sensitivity with transient simulations using the logical operator **B** in Eq. 10." width="500" >}}

Verifying this behaviour is best done by modifying the behavioural model commonly used for oscillators[^28] to accommodate multi-phase readout using the above expressions. Such a model is shown in Fig. 6. This configuration uses an internal time variable at V<sub>T<sub> that accumulates according to f<sub>osc<sub>. Given a set of quantisation levels L<sub>k<sub> or equivalently the number of phases, a logical function **B** will compute the corresponding PWM waveform of Q which are weighted by the associated capacitor C<sub>k<sub>. In this case the digital gate delay arising from computing the phase difference and applying feedback to the capacitive DAC can also be modelled by adjusting τ<sub>dly<sub>.

$$  \begin{split}\mathbf{B}(\phi_{S},\phi_{R},L) \triangleq & \left(\phi_{S} > L > \phi_{R} \right) \lor \left(\phi_{S} < \phi_{R} < L \right)   								 &  \lor \left( L < \phi_{S} < \phi_{R} \right)\end{split} $$

The logical expression in Eq. 10 simply compares the two phases with respect to L and evaluates the digital condition for which the output should be high. This representation implies that the delays correspond to the interval between each level which can be distributed uniformly as L<sub>k<sub>=(0.5+k)/L for integers k from 0 to N-1. By distributing the quantisation levels from 0 to 1 the corresponding delays are inherently normalised to the periodicity of φ\tss{S/R} without explicitly having to compute values with respect to f<sub>osc<sub> even when it is dynamically changing. In addition a difference in oscillator frequency between X\tss{1-2} can also be accommodated by adding a second integrated frequency component to the summation node.

{{< figure src="/images/jssc2018/dac_mm.svg" title="Figure 7: Simulated output spectrum with a 2.5 kHz input at -6 dB of the full input-range for a equivalent asynchronous flash quantiser with 2.6 bits of resolution and 5 % mismatch in σ\tss{τ,k} and σ<sub>C,k<sub>." width="500" >}}

{{< figure src="/images/jssc2018/dac_mm2.svg" title="Figure 8: Simulated output spectrum with a 2.5 kHz input at -6 dB of the full input-range for a asynchronous VCO quantiser with 2.6 bits of resolution, 300 kHz f<sub>osc<sub> and 5 % mismatch in σ\tss{τ,k} and σ<sub>C,k<sub>." width="500" >}}

Now the impact of mismatch can be simulated by adding parameter variation in the quantiser levels and the feedback weights (f). The analogous case where the mismatch is not modulated (i.e. f<sub>osc<sub> is 0) loosely corresponds to a flash-based ADC since the phase is simply being compared with N thresholds. The corresponding spectra of the flash quantiser is shown in Fig. 7 and oscillating quantiser is shown in Fig. 8 where we observe the distortion components in different bands of the spectrum.

# 12 Measured Results

{{< figure src="/images/jssc2018/micrograph.svg" title="Figure 9: Micro-photograph of the fabricated prototype showing an annotated floor plan in (a) and the poly layer together with the first three metal layers of the circuit layout in (b)." width="500" >}}

{{< figure src="/images/jssc2018/setup.svg" title="Figure 10: Experimental setup used for characterising the ATC for low-noise signal conversion showing the respective instruments that were used." width="500" >}}

The commercially available TSMC 65 nm CMOS LP MS RF technology (1P9M 6X1Z1U RDL) was used to prototype the proposed circuit and demonstrate measured noise and linearity characteristics. The chip micro-photograph of this prototype is shown in Fig. 9. The setup used to take these measurements is shown in Fig. 10 and uses a custom PCB to regulate V<sub>DD<sub> on-board with additional decoupling.

The external biasing allows this setup to first tune the circuit sensitivity by adjusting the 1 μ A reference current which scales all bias currents proportionally and then using V<sub>C<sub> the oscillation frequency can be fine tuned as V<sub>R<sub> is controlled which modulates I<sub>M10<sub>. The supply voltage can be tuned but reducing the supply below 0.5 V limits the biasing current and reduces the circuit sensitivity. Similarly increasing the supply is mainly constrained by the buffers that digitise the oscillator waveform and can induce a large leakage current beyond a voltage of 0.65 V.

The tone generated by the Agilent signal generator is attenuated resistively by a factor of 10 to achieve a low-noise differential test signal at the input of the instrumentation circuit. Two phases from the asynchronous output Q are captured at 500 MS/s using high-speed digital scope which can then be post-processed off-line to investigate the features of separate PWM signals during different operating conditions. Both the chopper tones and PWM carrier can be observed outside the signal bandwidth at harmonics of 78 kHz and 350 kHz respectively.

The characterisation procedure evaluates the signal to noise and distortion ratio (SNDR) for varying input amplitudes and frequencies. For a particular device, this characteristic is shown in Fig. 11. In extension, Fig. 12-13 show the distortion components as a function of amplitude along SA and the frequency along SF respectively. Fig. 14 shows what the input-referred power-spectral-density of Q looks like for a particular operating point at P. Here the lowest gain setting of 41 dB was used to demonstrate operation with maximum dynamic range. Although the circuit bandwidth theoretically exceeds the range of frequencies resolved here, the interfering tones seen in Fig. 14 prevent inaccurate measurements to confirm this result. Using a similar procedure the CMRR is characterised and shown in Fig. 15. Again, Fig. 17-16 show the distortion components due to a common mode input as a function of amplitude along SA and frequency along SF respectively. Due to the limited voltage overhead from the current sources in the transcondutor the high-frequency common-mode interference can result in degenerated operation as they are not attenuated by the pseudo-resistor. This mode of failure where the oscillators are saturated is out-lined by the dashed region.

Note that flicker noise from each oscillator is not removed by the chopper configuration in Fig. 4. However there is no apparent 1/f noise profile in the 10-100 Hz band even though the oscillators are small in size. This is because the rms-gate-voltage fluctuation due to flicker noise at each device is scaled by the open-loop gain of the ATC when referred to the input.

The maximum achieved THD was 60 dB for a 1 kHz sinusoidal input. The main source of performance degeneration in this circuit for larger input signals is due to the use of poorly regulated bias currents in the differential pair and relying on pseudo-differential phase read-out that allows some common-mode fluctuation at V<sub>S<sub> to couple to the output Q. Either introducing cascodes or using a folded cascode topology may improve linearity at the cost of increasing the required voltage headroom or reducing the noise efficiency. However the dynamic range exceeding 50 dB should be sufficient for the physiological range of amplitudes for neural activity given that there are no external aggressors present during recording. We can further confirm the effectiveness of the mismatch rejection technique as the Monte Carlo simulation results indicate that each phase should exhibit 1.1 % standard deviation in coupling factor for a 3-σ\: confidence interval. This should lead to a similar distortion characteristic shown in Fig. 7 with a large number of dominant harmonics being generated due to mismatch errors. Instead distortion is dominated by the second and third harmonic typical of more conventional analogue nonlinearity.

{{< figure src="/images/jssc2018/sndr_dm_sweep.svg" title="Figure 11: Characterisation sweep evaluating the SNDR performance using differential sinusoid at the input with varying amplitudes and frequencies. " width="500" >}}

{{< figure src="/images/jssc2018/thd_dm_vid.svg" title="Figure 12: Measured output harmonics due to a differential-mode 1 kHz input signal at different amplitudes corresponding to the SNDR measurement along SA in Fig. 11." width="500" >}}

{{< figure src="/images/jssc2018/thd_dm_frq.svg" title="Figure 13: Measured output harmonics due to a differential-mode 1.5 mVpp input signal at different frequencies corresponding to the SNDR measurement along SF in Fig. 11." width="500" >}}

{{< figure src="/images/jssc2018/spec_1k.svg" title="Figure 14: Measured output spectrum due to a differential 2 mVpp input signal at 1 kHz corresponding to the SNDR measurement at point P in Fig. 11." width="500" >}}

{{< figure src="/images/jssc2018/cmrr_cm_sweep.svg" title="Figure 15: Characterisation sweep evaluating the CMRR performance using large common-mode sinusoid at the input with varying amplitudes and frequencies." width="500" >}}

{{< figure src="/images/jssc2018/thd_cm_frq.svg" title="Figure 16: Measured output harmonics due to a common-mode 10 mVpp input signal at different frequencies corresponding to the CMRR measurement along SF in Fig. 15." width="500" >}}

{{< figure src="/images/jssc2018/thd_cm_vid.svg" title="Figure 17: Measured output harmonics due to a common-mode 1 kHz input signal at different amplitudes corresponding to the CMRR measurement along SA in Fig. 15." width="500" >}}

{{< figure src="/images/jssc2018/ccouple.svg" title="Figure 18: Measured frequency response due to differential 2 mVpp input signal that is capacitively coupled to the ATC input using 0.47 nF capacitors." width="500" >}}

The input impedance of this circuit was estimated by removing the resistive attenuation network and instead capacitively coupling the signal generator to the input. This assumes that the input will exhibit a RC time constant that is dominated by the coupling capacitor and the resistive/leakage component from the chopper in combination with the ESD protection that can be measured directly. The frequency dependent response is shown in Fig. 18. The 3dB cut-off frequency was estimated at 21.8 Hz. In this case two 0.47 nF capacitors were used to couple both inputs which implies the input resistance is around 31 MΩ. Parasitics at the input or capacitor variation can inflate this value and it is likely the impedance is closer to the analytical estimate of 22 MΩ \:according to Eq.6.

Table 2: System Characteristics and Comparison with State-of-the-Art
|		Parameter  [unit]	| This Work | [^8] | [^29] | [^7] | [^6] | [^30] | [^31] | [^32] | [^33] | [^34] |
|----|----|----|----|----|----|----|----|----|----|----|
|		Year								| **2017**			| 2017		| 2017		| 2017		| 2017		| 2016		| 2016		| 2015		| 2013 		| 2012 |
|		Application 						| **EAP** 			| ECG		| LFP		| -			| LFP		| ECG		| EAP		| EAP 		| EAP 		| EAP	|
|		Technology[nm]				| **65**			| 40		| 130		| 40		| 40		| 65		| 65		| 90		| 180		| 65|
|		Modality 							| **Time**			| Time		| Volt. 	| Time		| Volt.		| Volt.		| Volt.		| Volt.		| Volt.		| Mix |
|		Supply-V[V]					| **0.5** 			| 0.6		| 1.2		| 1.2		| 1.2		| 0.6 		| 1			| 1			| 0.45 		| 0.5 |
|		Supply-I[A]					| \textbf{2.55 μ}	| 5.5 μ	| 5.3 μ	| 14 μ	| 2.5 μ	| 3 n 		| 3.3 μ	| 2.8 μ | 2.1 μ	| 10 μ |
|		Bandwidth[Hz]					| **11 k** 		| 150		| 500		| 5 k		| 200		| 370		| 8.2 k	| 10.5 k	| 10 k 	| 10 k	|
|		Input Range[mVpp] 		| **4**  			| 40 		| - 		| 8 		| 100 		| 25 		| 220 		| 1 		| 1 		| 1 |
|		CMRR[dB] 				| \textbf{(>)60(^\star)}  		| 60 		| 90 		| 97 		| - 		| 60 		| (>)80 	| (>)45 	| 73 		| 75 |
|		SFDR[dB] 				| **60**  			| 56 		| 72 		| 70 		| 79 		| 75 		| (>)40 	| (>)37 	| (>)46 	| (>)34 |
|		Noise Floor[V/\rtxt{Hz}]		| **36 n**		| 0.6 μ | 46n		| 32 n		| -			| 1.4 μ	| 27.5n		| 35n		| 29n 		| 100n	|
|		RMS Noise[μ V<sub>rms<sub>]	| **3.8**		| 7.8		| 1.1 		| 2.3		| 5.2		| 26		| 4.1		| 3.04 		| 3.2 μ | 4.9 μ	|
|		Area[mm²]				| **0.006**		| 0.015		| 0.013		| 0.015		| 0.135		| 0.15		| 0.042		| 0.137		| 0.25 		| 0.013 |
|		NEF / PEF							| \textbf{2.2 / 2.4}		| 8.1 / 39| 2.9 / 10| 4.7 / 27| 22 / 581| 2.1 / 2.6| 3.2 / 10| 1.9 / 3.6 | 1.57 / 1.1	| 5.99 / 18 |


{{< figure src="/images/jssc2018/breakdown.svg" title="Figure 19: Power and area contributions from each sub-circuit." width="500" >}}

The detailed system characteristics are summarised in Table 2. The system power dissipation was specified at 1.3 μ W from these measurements. The relative power and area utilisation of each subcircuit is compared in Fig 19. As expected, a large fraction of both power and area is used by the main analogue circuits that consists of the low-noise transconductor and the flicker rejection stage. This distribution maximises the NEF and shows that the asynchronous digital logic can provide additional functionality without a significant resource overhead. In relation to the work in [^7], this ATC topology exhibits as significant reduction in power budget although input-referred noise figure is slightly increased. This improvement is not as pronounced in comparison with [^8] but instead the figure of merit is superior. Other works show that both time-based and voltage-based instrumentation can achieve near ideal noise efficiency but only select topologies enable more advanced CMOS process to yield a smaller silicon footprint. The pioneering work in [^34] already demonstrated that resource efficient signal acquisition is best realised by combing signal quantisation and amplification into a single loop. The main drawback was that this mixed signal topology was still relatively complex for hundreds of channels and linearising the feedback for closed loop quantisation came with a considerable reduction in noise efficiency. However the ΣΔ operation of the clocked VCO and the ΣΔ modulated DAC in the feedback enable a powerful technique that trades off excessive bandwidth for reduced circuit size or DAC complexity. The same technique is applied here to enable a compact multichannel configuration. Our future work will extend on the current prototype by additionally providing electrode off-set cancellation for \textit{in-vivo} experiments with multi-channel recording capabilities.

# 13 Conclusion

This work proposes a chopper-stabilised ATC to enable high-impedance electrode instrumentation for integrated sensing systems that require ultra low-voltage operation for power saving. The time-domain techniques enabled by this ATC topology alleviate the difficulty of performing precise instrumentation in advanced CMOS technologies while also providing improved power efficiency together with a substantial reduction in size. The presented configuration achieves a power budget of 1.2 μ W for a 36 nV/\rtxt{Hz} noise floor requirement and a compact silicon footprint of 0.006 mm². In extension to presenting the implementation details, this work also provides essential modelling and analytical tools for further optimisation. This will enable other mixed-signal systems that require high noise-efficiency, high-speed, or asynchronous signal conversion to effectively adopt time-based techniques and utilise the presented circuit implementation.

# 14 Acknowledgement

The authors would like to thank Dr. Pantelis Georgiou, and the Europractice Advanced Technology Stimulation programme for providing access to the TSMC 65 nm technology. The authors additionally thank Yan Liu and the anonymous reviewers for their valuable assistance with this manuscript.

# Refernces:

[^18]: J.Guo, J.Yuan, and M.Chan, ''Modeling of the cell-electrode interface noise  for microelectrode arrays,'' IEEE Trans. Biomed. Circuits Syst.,  vol.6, no.6, pp. 605--613, Dec 2012.
[^2]: C.Huang and S.Chakrabartty, ''An asynchronous analog self-powered cmos  sensor-data-logger with a 13.56 MHz RF programming interface,''  IEEE J. Solid-State Circuits, vol.47, no.2, pp. 476--489, Feb  2012.
[^1]: J.Yoo etal., ''An 8-channel scalable EEG acquisition SoC with  patient-specific seizure classification and recording processor,''  IEEE J. Solid-State Circuits, vol.48, no.1, pp. 214--228, Jan  2013.
[^5]: K.Lee, Y.Yoon, and N.Sun, ''A scaling-friendly low-power small-area $\Delta  \Sigma$ ADC with VCO-based integrator and intrinsic mismatch shaping  capability,'' IEEE Trans. Emerg. Sel. Topics Circuits Syst., vol.5,  no.4, pp. 561--573, Dec 2015.
[^8]: R.Mohan etal., ''A 0.6 V, 0.015-mm$^2$, time-based ECG readout  for ambulatory applications in 40 nm CMOS,'' IEEE J. Solid-State  Circuits, vol.52, no.1, pp. 298--308, Jan 2017.
[^6]: W.Jiang etal., ''A ±50 mV linear-input-range VCO-based  neural-recording front-end with digital nonlinearity correction,''  IEEE J. Solid-State Circuits, vol.52, no.1, pp. 173--184, Jan  2017.
[^4]: P.Prabha etal., ''A highly digital VCO-based ADC architecture for  current sensing applications,'' IEEE J. Solid-State Circuits,  vol.50, no.8, pp. 1785--1795, Aug 2015.
[^3]: T.Anand, K.A.A. Makinwa, and P.K. Hanumolu, ''A VCO based highly digital  temperature sensor with 0.034 $^\circ$C/mV supply sensitivity,''  IEEE J. Solid-State Circuits, vol.51, no.11, pp. 2651--2663, Nov  2016.
[^10]: B.Vigraham, J.Kuppambatti, and P.R. Kinget, ''Switched-mode operational  amplifiers and their application to continuous-time filters in nanoscale  CMOS,'' IEEE J. Solid-State Circuits, vol.49, no.12, pp.  2758--2772, Dec 2014.
[^23]: L.B. Leene and T.G. Constandinou, ''A 0.5V time-domain instrumentation  circuit with clocked and unclocked
Delta
Sigma operation,'' in  2017 IEEE International Symposium on Circuits and Systems (ISCAS), May  2017, pp. 1--4.
[^12]: Y.Chen etal., ''A continuous-time digital IIR filter with  signal-derived timing and fully agile power consumption,'' IEEE J.  Solid-State Circuits, vol.53, no.2, pp. 418--430, Feb 2018.
[^22]: S.Pavan, ''Analysis of chopped integrators, and its application to  continuous-time delta-sigma modulator design,'' IEEE Trans. Circuits  Syst. I, vol.64, no.8, pp. 1953--1965, Aug 2017.
[^24]: W.S.T. Yan and H.C. Luong, ''A 900-MHz cmos low-phase-noise  voltage-controlled ring oscillator,'' IEEE Trans. Circuits Syst.  II, vol.48, no.2, pp. 216--221, Feb 2001.
[^17]: R.R. Harrison and C.Charles, ''A low-power low-noise CMOS amplifier for  neural recording applications,'' IEEE J. Solid-State Circuits,  vol.38, no.6, pp. 958--965, June 2003.
[^19]: A.Hajimiri and T.H. Lee, ''A general theory of phase noise in electrical  oscillators,'' IEEE J. Solid-State Circuits, vol.33, no.2, pp.  179--194, Feb 1998.
[^25]: T.Denison etal., ''A 2
muW 100 nV/rtHz chopper-stabilized  instrumentation amplifier for chronic measurement of neural field  potentials,'' IEEE J. Solid-State Circuits, vol.42, no.12, pp.  2934--2945, Dec 2007.
[^14]: Y.Li, D.Zhao, and W.A. Serdijn, ''A sub-microwatt asynchronous  level-crossing ADC for biomedical applications,'' IEEE Trans.  Biomed. Circuits Syst., vol.7, no.2, pp. 149--157, April 2013.
[^13]: W.Tang etal., ''Continuous time level crossing sampling ADC for  bio-potential recording systems,'' IEEE Trans. Circuits Syst. I,  vol.60, no.6, pp. 1407--1418, June 2013.
[^9]: G.D. Colletta etal., ''A 20 nW 0.25 V inverter-based  asynchronous delta-sigma modulator in 130 nm digital CMOS process,''  IEEE Trans. VLSI Syst., vol.25, no.12, pp. 3455--3463, Dec 2017.
[^16]: F.M. Yaul and A.P. Chandrakasan, ''A noise-efficient 36 nV/
txtHz  chopper amplifier using an inverter-based 0.2 V supply input stage,''  IEEE J. Solid-State Circuits, vol.52, no.11, pp. 3032--3042, Nov  2017.
[^29]: H.Kassiri etal., ''Rail-to-rail-input dual-radio 64-channel  closed-loop neurostimulator,'' IEEE J. Solid-State Circuits,  vol.52, no.11, pp. 2793--2810, Nov 2017.
[^28]: C.C. Kuo etal., ''Fast statistical analysis of process variation  effects using accurate PLL behavioral models,'' IEEE Trans.  Circuits Syst. I, vol.56, no.6, pp. 1160--1172, June 2009.
[^7]: C.C. Tu, Y.K. Wang, and T.H. Lin, ''A low-noise area-efficient chopped  VCO-based CTDSM for sensor applications in 40 nm CMOS,'' IEEE  J. Solid-State Circuits, vol.52, no.10, pp. 2523--2532, Oct 2017.
[^31]: K.A. Ng and Y.P. Xu, ''A low-power, high CMRR neural amplifier system  employing CMOS inverter-based OTAs with CMFB through supply rails,''  IEEE J. Solid-State Circuits, vol.51, no.3, pp. 724--737, March  2016.
[^30]: P.Harpe etal., ''A 0.20$ $mm$^2$ 3$ $nW signal acquisition IC  for miniature sensor nodes in 65 nm CMOS,'' IEEE J. Solid-State  Circuits, vol.51, no.1, pp. 240--248, Jan 2016.
[^32]: T.Yang and J.Holleman, ''An ultralow-power low-noise CMOS biopotential  amplifier for neural recording,'' IEEE Trans. Circuits Syst. II,  vol.62, no.10, pp. 927--931, Oct 2015.
[^21]: S.Mondal and D.A. Hall, ''An ECG chopper amplifier achieving 0.92 NEF  and 0.85 PEF with AC-coupled inverter-stacking for noise efficiency  enhancement,'' May 2017, pp. 1--4.
[^11]: L.B. Leene and T.G. Constandinou, ''Time domain processing techniques using  ring oscillator-based filter structures,'' IEEE Trans. Circuits Syst.  I, vol.64, no.12, pp. 3003--3012, Dec 2017.
[^33]: D.Han etal., ''A 0.45 V 100-channel neural-recording IC with  sub-
mu w/channel consumption in 0.18
mu m CMOS,'' IEEE Trans.  Biomed. Circuits Syst., vol.7, no.6, pp. 735--746, Dec 2013.
[^34]: R.Muller, S.Gambini, and J.M. Rabaey, ''A 0.013 mm	sqrd, 5 W,  DC-coupled neural signal acquisition IC with 0.5 V supply,''  IEEE J. Solid-State Circuits, vol.47, no.1, pp. 232--243, Jan  2012.
[^15]: A.Bagheri etal., ''Low-frequency noise and offset rejection in  DC-coupled neural amplifiers: A review and digitally-assisted design  tutorial,'' IEEE Trans. Biomed. Circuits Syst., vol.11, no.1, pp.  161--176, Feb 2017.
[^20]: S.Chatterjee, Y.Tsividis, and P.Kinget, ''0.5-V analog circuit techniques  and their application in OTA and filter design,'' IEEE J.  Solid-State Circuits, vol.40, no.12, pp. 2373--2387, Dec 2005.
[^26]: C.C. Enz and E.A. Vittoz, Charge-based MOS transistor modeling: the  EKV model for low-power and RF IC design.\hskip 1em plus 0.5em minus  0.4em
elax John Wiley & Sons, Aug 2006.
[^27]: K.-D. Chen and T.-H. Kuo, ''An improved technique for reducing baseband tones  in sigma-delta modulators employing data weighted averaging algorithm without  adding dither,'' IEEE Trans. Circuits Syst. II, vol.46, no.1,  pp. 63--68, Jan 1999.
